@@ -9,7 +9,7 @@ from slai.clients.cli import get_cli_client
 
 from slai_cli import log
 from slai_cli.errors import handle_error
-from slai_cli.create.local_config_helper import LocalConfigHelper
+from slai_cli.init.local_config_helper import LocalConfigHelper
 from slai_cli.modules.model_watcher import ModelWatcher
 from slai_cli.modules.drive_client import DriveClient
 from slai_cli.modules.docker_client import DockerClient
